==> 0.5.0.tar.gz: lib/src/parse.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of passive_data;

/// Convert value to passive data structure.
dynamic deepConvertToPds(final dynamic value, [bool retry = true]) {
  // Check for num, bool, null, String
  if (value is num || value is bool || value == null || value is String) {
    return value;
  } else {
    // Check for List, Set, Map<String, Map<int
    if (value is List) {
      return toPdsList(value);
    } else if (value is Set) {
      return toPdsList(value.toList());
    } else if (value is Map<String, dynamic> || value is Map<int, dynamic>) {
      return toPdsMap(value);
    } else if (retry) {
      // Fallback to `.toPds()`
      try {
        var passive = value.toPds();
        return deepConvertToPds(passive, false);
      } catch (e) {
        throw new ArgumentError.value(
            value, 'value', 'cannot be converted to a passive data structure');
      }
    } else {
      throw new ArgumentError.value(
          value, 'value', 'cannot be converted to a passive data structure');
    }
  }
}

/// Convert List to passive data structure.
List toPdsList(final List list) {
  return new List.generate(list.length, (int i) => deepConvertToPds(list[i]));
}

/// Convert Map to passive data structure.
Map toPdsMap(final Map map) {
  return new Map.fromIterable(map.keys,
      value: (dynamic key) => deepConvertToPds(map[key]));
}

/// Convert Map<String, to passive data structure.
Map<String, dynamic> toPdsStringMap(final Map<String, dynamic> map) {
  return toPdsMap(map) as Map<String, dynamic>;
}

==> 0.5.1.tar.gz: lib/src/parse.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of passive_data;

/// Convert value to passive data structure.
dynamic deepConvertToPds(final dynamic value, [bool retry = true]) {
  // Check for num, bool, null, String
  if (value is num || value is bool || value == null || value is String) {
    return value;
  } else {
    // Check for List, Set, Map<String, Map<int
    if (value is List) {
      return toPdsList(value);
    } else if (value is Set) {
      return toPdsList(value.toList());
    } else if (value is Map<String, dynamic> || value is Map<int, dynamic>) {
      return toPdsMap(value);
    } else if (retry) {
      // Fallback to `.toPds()`
      try {
        var passive = value.toPds();
        return deepConvertToPds(passive, false);
      } catch (e) {
        throw new ArgumentError.value(
            value, 'value', 'cannot be converted to a passive data structure');
      }
    } else {
      throw new ArgumentError.value(
          value, 'value', 'cannot be converted to a passive data structure');
    }
  }
}

/// Convert List to passive data structure.
List toPdsList(final List list) {
  return new List.generate(list.length, (int i) => deepConvertToPds(list[i]));
}

/// Convert Map to passive data structure.
Map toPdsMap(final Map map) {
  return new Map.fromIterable(map.keys,
      value: (dynamic key) => deepConvertToPds(map[key]));
}

/// Convert Map<String, V> to passive data structure.
Map<String, dynamic> toPdsStringMap(final Map<String, dynamic> map) {
  return toPdsMap(map) as Map<String, dynamic>;
}

/// Convert Map<int, V> to passive data structure.
Map<int, dynamic> toPdsIntMap(final Map<int, dynamic> map) {
  return toPdsMap(map) as Map<int, dynamic>;
}
